==> mdm-rpc-0.1.11-sources.jar: com/chinayanghe/msp/mdm/vo/superchain/SChainTerminalRelationVo.java <==
package com.chinayanghe.msp.mdm.vo.superchain;

import java.util.Date;

/**
 * Created by isshu on 2017/5/12.
 */
public class SChainTerminalRelationVo {

    private String id;
    /** 连锁商超编码*/
    private String code;
    /**  连锁商超名称*/
    private String scName;
    /** 终端名称*/
    private String terminalName;
    /**  终端编码*/
    private String terminalCode;
    /** 启用状态*/
    private Integer enableStatus;
    /** 创建时间*/
    private Date createDate;
    /** 创建人ID*/
    private String createName;
    /** 修改时间*/
    private Date updateDate;
    /** 修改人*/
    private String updateName;
    /** 创建岗位*/
    private String positionCode;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getScName() {
        return scName;
    }

    public void setScName(String scName) {
        this.scName = scName;
    }

    public String getTerminalName() {
        return terminalName;
    }

    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
}

==> mdm-rpc-0.1.93-sources.jar: com/chinayanghe/msp/mdm/vo/superchain/SChainTerminalRelationVo.java <==
package com.chinayanghe.msp.mdm.vo.superchain;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by isshu on 2017/5/12.
 */
public class SChainTerminalRelationVo implements Serializable {

    private static final long serialVersionUID = -850735235327292805L;
    private String id;
    /** 连锁商超编码*/
    private String code;
    /**  连锁商超名称*/
    private String scName;
    /** 终端名称*/
    private String terminalName;
    /**  终端编码*/
    private String terminalCode;
    /** 启用状态*/
    private Integer enableStatus;
    /** 创建时间*/
    private Date createDate;
    /** 创建人ID*/
    private String createName;
    /** 修改时间*/
    private Date updateDate;
    /** 修改人*/
    private String updateName;
    /** 创建岗位*/
    private String positionCode;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getTerminalCode() {
        return terminalCode;
    }

    public void setTerminalCode(String terminalCode) {
        this.terminalCode = terminalCode;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getUpdateName() {
        return updateName;
    }

    public void setUpdateName(String updateName) {
        this.updateName = updateName;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getScName() {
        return scName;
    }

    public void setScName(String scName) {
        this.scName = scName;
    }

    public String getTerminalName() {
        return terminalName;
    }

    public void setTerminalName(String terminalName) {
        this.terminalName = terminalName;
    }
}
